==> gss_0.9-3.tar.gz: gss/data/LakeAcidity.R <==
"LakeAcidity" <-
structure(list(ph = c(6.4, 6.33, 6.94, 6.89, 6.82, 6.12, 6.46, 
6.75, 6.32, 6.05, 5.95, 7.17, 6.23, 6.59, 6.85, 6.61, 6.98, 6.54, 
7.07, 6.54, 6.52, 6.72, 6.72, 6.75, 6.55, 6.51, 6.37, 6.91, 6.96, 
6.95, 6.68, 6.76, 6.5, 6.75, 6.39, 6.52, 6.47, 6.26, 6.28, 6.2, 
6.83, 6.54, 6.45, 6.7, 6.73, 6.82, 6.84, 6.59, 6.77, 6.64, 7, 
6.97, 6.35, 6.37, 6.7, 6.56, 6.97, 7.63, 6.31, 6.32, 5.87, 7.04, 
7.05, 6.88, 6.99, 6.76, 6.46, 6.3, 6.34, 6.49, 6.83, 7.43, 6.88, 
6.92, 7.04, 7.2, 6.97, 7.25, 6.9, 8.05, 7.4, 6.85, 6.38, 7.27, 
6.65, 6.9, 7.11, 6.82, 7.19, 7.03, 6.69, 6.4, 6.46, 6.52, 7.15, 
6.36, 6.66, 7.04, 7.29, 7.36, 6.77, 6.42, 8.17, 7.09, 7.35, 7.32, 
6.7, 7.44, 6.68, 6.91, 7.11, 6.53), cal = c(1.6, 1.61, 3.81, 
2.51, 2.92, 0.85, 0.8, 1.78, 0.92, 0.96, 0.33, 3.395, 0.63, 1.08, 
4.63, 2.22, 23.52, 1.47, 3.06, 1, 1.58, 15.38, 1.38, 2.74, 1.39, 
1.1, 1.03, 2.29, 1.33, 1.99, 1.84, 1.35, 1.1, 1.15, 0.54, 1.87, 
1.93, 0.8, 0.71, 0.58, 0.92, 1.8, 1.25, 1.09, 1.11, 1.07, 0.645, 
0.86, 1.06, 3.77, 2.37, 1.42, 1, 1.66, 0.99, 0.68, 3.35, 30.97, 
1.64, 1.69, 0.29, 1.85, 1.56, 1.12, 7.21, 2.24, 0.94, 1.71, 2.08, 
0.59, 1.65, 4.45, 1.81, 1.48, 2.055, 1.68, 3.19, 5.25, 5.83, 
5.06, 3.77, 1.8, 1.48, 4.32, 1.52, 2.73, 3.75, 5.66, 5.51, 2.21, 
3.37, 1.52, 2.22, 1.54, 5.645, 1.84, 2.23, 5.4, 5.34, 6.23, 2.4, 
2.03, 1.36, 9.16, 5.09, 15.83, 2.21, 4.23, 1.28, 2.77, 5.75, 
0.71), lat = c(35.4958, 35.45, 35.3978, 35.5333, 35.5411, 35.4167, 
35.1333, 35.1069, 35.1014, 35.1125, 35.1058, 36.8011, 36.4447, 
36.4014, 36.1378, 35.6542, 35.6931, 35.45, 35.2772, 35.1833, 
35.1703, 35.095, 34.8597, 34.7869, 34.9322, 34.8272, 34.7703, 
34.6072, 34.6217, 34.6225, 34.4897, 34.5447, 34.4522, 34.4261, 
34.5119, 35.4083, 35.338, 35.2542, 35.2403, 35.213, 35.2625, 
35.225, 35.0625, 34.9753, 35.0292, 35.1014, 34.8661, 34.6886, 
34.6139, 34.6028, 34.6536, 34.4897, 35.175, 35.1625, 34.8625, 
34.53, 34.5017, 35.6708, 35.0853, 35.3667, 35.1306, 34.7392, 
36.1375, 35.9444, 37.3167, 35.7417, 35.6667, 35.1944, 35.0875, 
34.9514, 34.6269, 34.2908, 34.0117, 34.0981, 34, 33.95, 33.6917, 
33.7167, 33.6972, 33.4811, 33.4167, 33.3944, 33.2361, 33.618, 
34.375, 35.7847, 33.5144, 36.338, 33.6392, 33.4958, 33.9822, 
34.0689, 35.3642, 35.725, 33.9194, 35.2231, 35.1083, 33.6833, 
34.4583, 33.6644, 34.5333, 35.095, 33.9872, 37.0625, 34.2639, 
37.0417, 34.1917, 34.1964, 35.0125, 36.1783, 36.3278, 35.2681
), lon = c(83.9667, 83.9292, 84.1139, 82.6555, 82.5625, 82.9278, 
82.9417, 83.1008, 83.0792, 83.0208, 83.0042, 80.1103, 80.93, 
80.9819, 81.6722, 83.9078, 83.0458, 83.7917, 83.6544, 83.6667, 
84.2583, 84.6164, 84.6511, 84.3994, 84.0755, 83.555, 83.4289, 
84.6344, 83.8247, 83.8203, 84.3717, 84.3678, 84.2881, 84.298, 
84.0769, 82.2025, 82.2042, 83.0958, 83.0617, 83, 82.5181, 82.4167, 
83.2208, 82.9378, 82.6972, 82.5467, 83.103, 83.3386, 83.3594, 
83.2825, 83.1911, 83.4969, 83.15, 84.1667, 84.2667, 84.2792, 
84.3972, 83.7978, 83.1611, 83.875, 82.6653, 83.9736, 81.7333, 
82.4944, 79.2708, 81.9, 82.3389, 82.2347, 81.743, 82.3936, 83.4292, 
84.0814, 83.7433, 83.3555, 83.8028, 83.275, 84.1375, 84.0542, 
82.6972, 84.3, 83.3944, 84.2425, 82.8292, 84.19, 82.8417, 81.4583, 
84.2917, 82.118, 83.0847, 84.2258, 84.3306, 83.5208, 81.8792, 
82.0833, 84.1436, 81.7292, 82.05, 84.0458, 82.2083, 84.0417, 
82.3833, 81.7389, 83.6805, 80.6083, 84.1625, 79.5833, 84, 84.315, 
83.7875, 82.1564, 82.0833, 82.9694), geog = structure(c(-0.0285729739177452, 
-0.0280389786604092, -0.0306689628259679, -0.00989601238908527, 
-0.00857099227253307, -0.0137754514718356, -0.0139734761978876, 
-0.0162400142900541, -0.0159323077171262, -0.0151003491033841, 
-0.0148638648155683, 0.0263642926953068, 0.0146886377000688, 
0.0139492573904064, 0.00411421994907986, -0.0277342399693222, 
-0.0154564977410216, -0.0260808950289926, -0.0241255096370081, 
-0.0243006883612875, -0.0327248857769846, -0.0378224791520372, 
-0.038316362182264, -0.0347336236482314, -0.0301222020659227, 
-0.0227097975711577, -0.0209137109163452, -0.0380786738214911, 
-0.0265508492242766, -0.0264881891703901, -0.0343392951693743, 
-0.0342837753505742, -0.033149143601061, -0.0332900863357114, 
-0.030142136291108, -0.0034417007500663, -0.00346592288314423, 
-0.0161687861203944, -0.0156830067479059, -0.0148040312429853, 
-0.00793839384498335, -0.00649365854878693, -0.0179494520118666, 
-0.0139179153860286, -0.0104901260545428, -0.00834587898790771, 
-0.016271354645556, -0.0196274735035871, -0.0199237541116407, 
-0.0188283577308815, -0.0175263732173187, -0.0218822719740606, 
-0.0169408927983368, -0.0314207363276367, -0.0328444761316895, 
-0.0330224366613708, -0.034702305436455, -0.0261677660064001, 
-0.0170990161190523, -0.0272671563497637, -0.0100356367069745, 
-0.0286712277186204, 0.00324364907961499, -0.0076007210871142, 
0.038316362182264, 0.000868442320612986, -0.00538515925510863, 
-0.00390049590829047, 0.0031054402461575, -0.00616452945327698, 
-0.0209179840455323, -0.0302062104643991, -0.0253916132696815, 
-0.0198682016964616, -0.0262389715044315, -0.0187215226867601, 
-0.03100498605724, -0.0298189148571299, -0.0104901260545428, 
-0.0333185594948998, -0.0204222972651778, -0.0324999401108173, 
-0.0123707354974978, -0.031752476413745, -0.01254882026577, 0.00716188704522074, 
-0.0332003956193006, -0.00223771487099994, -0.0160106591444389, 
-0.0322621783976463, -0.0337541937475376, -0.0222226854484733, 
0.00116480966385076, -0.00174329544240137, -0.0310918386663076, 
0.00330206721861086, -0.00126882316819435, -0.0296993074985592, 
-0.00352434095620861, -0.029640927484413, -0.00601777459532289, 
0.00316385842396567, -0.0244972290111338, 0.0192713635840969, 
-0.0313609371311681, 0.033868083472902, -0.0290471514531749, 
-0.0335321068923668, -0.0260210820529724, -0.00278485240989986, 
-0.00174329544240137, -0.0143680985477109, 0.00382924302071701, 
0.00302988694560757, 0.00211882812652856, 0.00448373582481789, 
0.00461987009606946, 0.00244869449343668, -0.00249756356303633, 
-0.00295832876704121, -0.00305432144207063, -0.00286059074264511, 
-0.00297752730425607, 0.0266078944614089, 0.0203892686745009, 
0.0196336924606284, 0.0150336998193221, 0.00659380613187579, 
0.00727272287945427, 0.00302988694560757, 1.39626340156422e-05, 
-0.00162490081856744, -0.00185179327802176, -0.00316602197388728, 
-0.00727272287945415, -0.00854328275936673, -0.00600738715164509, 
-0.0078399386845707, -0.00883299647922343, -0.0116794778047243, 
-0.0114264219533161, -0.0114124602297189, -0.0137300738015307, 
-0.012770227019369, -0.0143845075892684, -0.0148399898855175, 
-0.0133426462096598, 0.00230208725001663, 0.00107512261210817, 
-0.000387463084247843, -0.000630063818282825, -0.00110653851995145, 
-0.000242600763647396, -0.000897099115195977, -0.00373325059814289, 
-0.00525516218905541, -0.0043144405256996, -0.00305432144207063, 
-0.00716102471630075, -0.0102588653868162, -0.011562548641229, 
-0.011756267019343, -0.0108696965270507, -0.0137300738015307, 
-0.00176976293768666, -0.00198792870868294, -0.00722385494415798, 
-0.0130267690754334, -0.0135206537338557, 0.00688352420847699, 
-0.0033353180166581, 0.00157603166210573, -0.00254468730307405, 
-0.00937577137327698, 0.0150284644230919, 0.0116585352796735, 
0.035602427227657, 0.00812092774507058, 0.00681196738692728, 
-0.00143116949807027, -0.00329692098423761, -0.00567228965101078, 
-0.0113356707102379, -0.0172011167548293, -0.0220713866586688, 
-0.0205637650058842, -0.0222755399750203, -0.0231479794735675, 
-0.0276547064687462, -0.0272185384186896, -0.0275587499465788, 
-0.0313287689747825, -0.0324521892569128, -0.0328411902119455, 
-0.035602427227657, -0.0289404989272623, -0.0157317489022199, 
0.00887139221830571, -0.0307478543642401, 0.0185273552164884, 
-0.0285706421369684, -0.0310723304847896, -0.022586130415522, 
-0.0210732906889953, 0.00153239848350925, 0.0078294670304622, 
-0.0236819037935701, -0.000930260357140665, -0.0029338942635551, 
-0.0278012577559568, -0.0142780534387062, -0.0281309959625725, 
-0.0129691780756645, -0.00316602197388728, -0.0224988861286345, 
0.0311682770989707, -0.0176705389489535, 0.0308054229456411, 
-0.0189304555542258, -0.0188484397154081, -0.00460590761060793, 
0.0157404744679444, 0.0183493618972045, -0.000144862327408782
), .Dim = c(112, 2), .Dimnames = list(NULL, c("x", "y")), class = "AsIs")), .Names = c("ph", 
"cal", "lat", "lon", "geog"))

==> gss_1.1-7.tar.gz: gss/data/LakeAcidity.R <==
LakeAcidity <-
structure(list(ph = c(6.4, 6.33, 6.94, 6.89, 6.82, 6.12, 6.46, 
6.75, 6.32, 6.05, 5.95, 7.17, 6.23, 6.59, 6.85, 6.61, 6.98, 6.54, 
7.07, 6.54, 6.52, 6.72, 6.72, 6.75, 6.55, 6.51, 6.37, 6.91, 6.96, 
6.95, 6.68, 6.76, 6.5, 6.75, 6.39, 6.52, 6.47, 6.26, 6.28, 6.2, 
6.83, 6.54, 6.45, 6.7, 6.73, 6.82, 6.84, 6.59, 6.77, 6.64, 7, 
6.97, 6.35, 6.37, 6.7, 6.56, 6.97, 7.63, 6.31, 6.32, 5.87, 7.04, 
7.05, 6.88, 6.99, 6.76, 6.46, 6.3, 6.34, 6.49, 6.83, 7.43, 6.88, 
6.92, 7.04, 7.2, 6.97, 7.25, 6.9, 8.05, 7.4, 6.85, 6.38, 7.27, 
6.65, 6.9, 7.11, 6.82, 7.19, 7.03, 6.69, 6.4, 6.46, 6.52, 7.15, 
6.36, 6.66, 7.04, 7.29, 7.36, 6.77, 6.42, 8.17, 7.09, 7.35, 7.32, 
6.7, 7.44, 6.68, 6.91, 7.11, 6.53), cal = c(1.6, 1.61, 3.81, 
2.51, 2.92, 0.85, 0.8, 1.78, 0.92, 0.96, 0.33, 3.395, 0.63, 1.08, 
4.63, 2.22, 23.52, 1.47, 3.06, 1, 1.58, 15.38, 1.38, 2.74, 1.39, 
1.1, 1.03, 2.29, 1.33, 1.99, 1.84, 1.35, 1.1, 1.15, 0.54, 1.87, 
1.93, 0.8, 0.71, 0.58, 0.92, 1.8, 1.25, 1.09, 1.11, 1.07, 0.645, 
0.86, 1.06, 3.77, 2.37, 1.42, 1, 1.66, 0.99, 0.68, 3.35, 30.97, 
1.64, 1.69, 0.29, 1.85, 1.56, 1.12, 7.21, 2.24, 0.94, 1.71, 2.08, 
0.59, 1.65, 4.45, 1.81, 1.48, 2.055, 1.68, 3.19, 5.25, 5.83, 
5.06, 3.77, 1.8, 1.48, 4.32, 1.52, 2.73, 3.75, 5.66, 5.51, 2.21, 
3.37, 1.52, 2.22, 1.54, 5.645, 1.84, 2.23, 5.4, 5.34, 6.23, 2.4, 
2.03, 1.36, 9.16, 5.09, 15.83, 2.21, 4.23, 1.28, 2.77, 5.75, 
0.71), lat = c(35.4958, 35.45, 35.3978, 35.5333, 35.5411, 35.4167, 
35.1333, 35.1069, 35.1014, 35.1125, 35.1058, 36.8011, 36.4447, 
36.4014, 36.1378, 35.6542, 35.6931, 35.45, 35.2772, 35.1833, 
35.1703, 35.095, 34.8597, 34.7869, 34.9322, 34.8272, 34.7703, 
34.6072, 34.6217, 34.6225, 34.4897, 34.5447, 34.4522, 34.4261, 
34.5119, 35.4083, 35.338, 35.2542, 35.2403, 35.213, 35.2625, 
35.225, 35.0625, 34.9753, 35.0292, 35.1014, 34.8661, 34.6886, 
34.6139, 34.6028, 34.6536, 34.4897, 35.175, 35.1625, 34.8625, 
34.53, 34.5017, 35.6708, 35.0853, 35.3667, 35.1306, 34.7392, 
36.1375, 35.9444, 37.3167, 35.7417, 35.6667, 35.1944, 35.0875, 
34.9514, 34.6269, 34.2908, 34.0117, 34.0981, 34, 33.95, 33.6917, 
33.7167, 33.6972, 33.4811, 33.4167, 33.3944, 33.2361, 33.618, 
34.375, 35.7847, 33.5144, 36.338, 33.6392, 33.4958, 33.9822, 
34.0689, 35.3642, 35.725, 33.9194, 35.2231, 35.1083, 33.6833, 
34.4583, 33.6644, 34.5333, 35.095, 33.9872, 37.0625, 34.2639, 
37.0417, 34.1917, 34.1964, 35.0125, 36.1783, 36.3278, 35.2681
), lon = c(83.9667, 83.9292, 84.1139, 82.6555, 82.5625, 82.9278, 
82.9417, 83.1008, 83.0792, 83.0208, 83.0042, 80.1103, 80.93, 
80.9819, 81.6722, 83.9078, 83.0458, 83.7917, 83.6544, 83.6667, 
84.2583, 84.6164, 84.6511, 84.3994, 84.0755, 83.555, 83.4289, 
84.6344, 83.8247, 83.8203, 84.3717, 84.3678, 84.2881, 84.298, 
84.0769, 82.2025, 82.2042, 83.0958, 83.0617, 83, 82.5181, 82.4167, 
83.2208, 82.9378, 82.6972, 82.5467, 83.103, 83.3386, 83.3594, 
83.2825, 83.1911, 83.4969, 83.15, 84.1667, 84.2667, 84.2792, 
84.3972, 83.7978, 83.1611, 83.875, 82.6653, 83.9736, 81.7333, 
82.4944, 79.2708, 81.9, 82.3389, 82.2347, 81.743, 82.3936, 83.4292, 
84.0814, 83.7433, 83.3555, 83.8028, 83.275, 84.1375, 84.0542, 
82.6972, 84.3, 83.3944, 84.2425, 82.8292, 84.19, 82.8417, 81.4583, 
84.2917, 82.118, 83.0847, 84.2258, 84.3306, 83.5208, 81.8792, 
82.0833, 84.1436, 81.7292, 82.05, 84.0458, 82.2083, 84.0417, 
82.3833, 81.7389, 83.6805, 80.6083, 84.1625, 79.5833, 84, 84.315, 
83.7875, 82.1564, 82.0833, 82.9694), geog = structure(c(-0.0285729739177452, 
-0.0280389786604092, -0.0306689628259679, -0.00989601238908527, 
-0.00857099227253307, -0.0137754514718356, -0.0139734761978876, 
-0.0162400142900541, -0.0159323077171262, -0.0151003491033841, 
-0.0148638648155683, 0.0263642926953068, 0.0146886377000688, 
0.0139492573904064, 0.00411421994907986, -0.0277342399693222, 
-0.0154564977410216, -0.0260808950289926, -0.0241255096370081, 
-0.0243006883612875, -0.0327248857769846, -0.0378224791520372, 
-0.038316362182264, -0.0347336236482314, -0.0301222020659227, 
-0.0227097975711577, -0.0209137109163452, -0.0380786738214911, 
-0.0265508492242766, -0.0264881891703901, -0.0343392951693743, 
-0.0342837753505742, -0.033149143601061, -0.0332900863357114, 
-0.030142136291108, -0.0034417007500663, -0.00346592288314423, 
-0.0161687861203944, -0.0156830067479059, -0.0148040312429853, 
-0.00793839384498335, -0.00649365854878693, -0.0179494520118666, 
-0.0139179153860286, -0.0104901260545428, -0.00834587898790771, 
-0.016271354645556, -0.0196274735035871, -0.0199237541116407, 
-0.0188283577308815, -0.0175263732173187, -0.0218822719740606, 
-0.0169408927983368, -0.0314207363276367, -0.0328444761316895, 
-0.0330224366613708, -0.034702305436455, -0.0261677660064001, 
-0.0170990161190523, -0.0272671563497637, -0.0100356367069745, 
-0.0286712277186204, 0.00324364907961499, -0.0076007210871142, 
0.038316362182264, 0.000868442320612986, -0.00538515925510863, 
-0.00390049590829047, 0.0031054402461575, -0.00616452945327698, 
-0.0209179840455323, -0.0302062104643991, -0.0253916132696815, 
-0.0198682016964616, -0.0262389715044315, -0.0187215226867601, 
-0.03100498605724, -0.0298189148571299, -0.0104901260545428, 
-0.0333185594948998, -0.0204222972651778, -0.0324999401108173, 
-0.0123707354974978, -0.031752476413745, -0.01254882026577, 0.00716188704522074, 
-0.0332003956193006, -0.00223771487099994, -0.0160106591444389, 
-0.0322621783976463, -0.0337541937475376, -0.0222226854484733, 
0.00116480966385076, -0.00174329544240137, -0.0310918386663076, 
0.00330206721861086, -0.00126882316819435, -0.0296993074985592, 
-0.00352434095620861, -0.029640927484413, -0.00601777459532289, 
0.00316385842396567, -0.0244972290111338, 0.0192713635840969, 
-0.0313609371311681, 0.033868083472902, -0.0290471514531749, 
-0.0335321068923668, -0.0260210820529724, -0.00278485240989986, 
-0.00174329544240137, -0.0143680985477109, 0.00382924302071701, 
0.00302988694560757, 0.00211882812652856, 0.00448373582481789, 
0.00461987009606946, 0.00244869449343668, -0.00249756356303633, 
-0.00295832876704121, -0.00305432144207063, -0.00286059074264511, 
-0.00297752730425607, 0.0266078944614089, 0.0203892686745009, 
0.0196336924606284, 0.0150336998193221, 0.00659380613187579, 
0.00727272287945427, 0.00302988694560757, 1.39626340156422e-05, 
-0.00162490081856744, -0.00185179327802176, -0.00316602197388728, 
-0.00727272287945415, -0.00854328275936673, -0.00600738715164509, 
-0.0078399386845707, -0.00883299647922343, -0.0116794778047243, 
-0.0114264219533161, -0.0114124602297189, -0.0137300738015307, 
-0.012770227019369, -0.0143845075892684, -0.0148399898855175, 
-0.0133426462096598, 0.00230208725001663, 0.00107512261210817, 
-0.000387463084247843, -0.000630063818282825, -0.00110653851995145, 
-0.000242600763647396, -0.000897099115195977, -0.00373325059814289, 
-0.00525516218905541, -0.0043144405256996, -0.00305432144207063, 
-0.00716102471630075, -0.0102588653868162, -0.011562548641229, 
-0.011756267019343, -0.0108696965270507, -0.0137300738015307, 
-0.00176976293768666, -0.00198792870868294, -0.00722385494415798, 
-0.0130267690754334, -0.0135206537338557, 0.00688352420847699, 
-0.0033353180166581, 0.00157603166210573, -0.00254468730307405, 
-0.00937577137327698, 0.0150284644230919, 0.0116585352796735, 
0.035602427227657, 0.00812092774507058, 0.00681196738692728, 
-0.00143116949807027, -0.00329692098423761, -0.00567228965101078, 
-0.0113356707102379, -0.0172011167548293, -0.0220713866586688, 
-0.0205637650058842, -0.0222755399750203, -0.0231479794735675, 
-0.0276547064687462, -0.0272185384186896, -0.0275587499465788, 
-0.0313287689747825, -0.0324521892569128, -0.0328411902119455, 
-0.035602427227657, -0.0289404989272623, -0.0157317489022199, 
0.00887139221830571, -0.0307478543642401, 0.0185273552164884, 
-0.0285706421369684, -0.0310723304847896, -0.022586130415522, 
-0.0210732906889953, 0.00153239848350925, 0.0078294670304622, 
-0.0236819037935701, -0.000930260357140665, -0.0029338942635551, 
-0.0278012577559568, -0.0142780534387062, -0.0281309959625725, 
-0.0129691780756645, -0.00316602197388728, -0.0224988861286345, 
0.0311682770989707, -0.0176705389489535, 0.0308054229456411, 
-0.0189304555542258, -0.0188484397154081, -0.00460590761060793, 
0.0157404744679444, 0.0183493618972045, -0.000144862327408782
), .Dim = c(112L, 2L), .Dimnames = list(NULL, c("x", "y")), class = "AsIs")), .Names = c("ph", 
"cal", "lat", "lon", "geog"))
